@@ -7,8 +7,8 @@ from euphorie.client.tests.utils import MockMailFixture
 from euphorie.content.tests.utils import BASIC_SURVEY
 from euphorie.testing import EuphorieFunctionalTestCase
 from euphorie.testing import EuphorieIntegrationTestCase
-from z3c.appconfig.interfaces import IAppConfig
-from zope import component
+from plone import api
+from transaction import commit
 from zope.interface import alsoProvides
 
 import datetime
@@ -23,9 +23,8 @@ class GuestAccountTests(EuphorieFunctionalTestCase):
         self.logout()
         alsoProvides(self.portal.client.REQUEST, IClientSkinLayer)
         browser = self.get_browser()
-        appconfig = component.getUtility(IAppConfig)
-        allow_guest_accounts = appconfig["euphorie"].get("allow_guest_accounts", False)
-        appconfig["euphorie"]["allow_guest_accounts"] = True
+        api.portal.set_registry_record("euphorie.allow_guest_accounts", True)
+        commit()
         browser.open(self.portal.client.nl.absolute_url())
         self.assertTrue(re.search("run a test session", browser.contents) is not None)
         # No valid survey path is passed in came_from
@@ -39,7 +38,6 @@ class GuestAccountTests(EuphorieFunctionalTestCase):
         # Therefore we land on the "start new session" page
         self.assertTrue("Test session" in browser.contents)
         self.assertTrue("Start a new session" in browser.contents)
-        appconfig["euphorie"]["allow_guest_accounts"] = allow_guest_accounts
 
     def test_guest_login_with_valid_survey(self):
         self.loginAsPortalOwner()
@@ -47,9 +45,8 @@ class GuestAccountTests(EuphorieFunctionalTestCase):
         self.logout()
         alsoProvides(self.portal.client.REQUEST, IClientSkinLayer)
         browser = self.get_browser()
-        appconfig = component.getUtility(IAppConfig)
-        allow_guest_accounts = appconfig["euphorie"].get("allow_guest_accounts", False)
-        appconfig["euphorie"]["allow_guest_accounts"] = True
+        api.portal.set_registry_record("euphorie.allow_guest_accounts", True)
+        commit()
         browser.open(self.portal.client.nl.absolute_url())
         self.assertTrue(re.search("run a test session", browser.contents) is not None)
         url = "{}/ict/software-development".format(self.portal.client.nl.absolute_url())
@@ -58,7 +55,6 @@ class GuestAccountTests(EuphorieFunctionalTestCase):
         # Therefore we land on the start page of the survey
         self.assertTrue("Test session" in browser.contents)
         self.assertTrue("<h1>Software development</h1>" in browser.contents)
-        appconfig["euphorie"]["allow_guest_accounts"] = allow_guest_accounts
 
 
 class LoginTests(EuphorieFunctionalTestCase):
@@ -137,7 +133,7 @@ class RegisterTests(EuphorieIntegrationTestCase):
             view.request.form["password1"] = "secret"
             view.request.form["password2"] = "secret"
             self.assertEqual(view._tryRegistration(), False)
-            self.failUnless("email" in view.errors)
+            self.assertTrue("email" in view.errors)
 
     def testBasicEmailVerification(self):
         with self._get_view("register", self.portal.client) as view:
@@ -146,12 +142,12 @@ class RegisterTests(EuphorieIntegrationTestCase):
             view.request.form["password1"] = "secret"
             view.request.form["password2"] = "secret"
             self.assertEqual(view._tryRegistration(), False)
-            self.failUnless("email" in view.errors)
+            self.assertTrue("email" in view.errors)
 
             view.errors.clear()
             view.request.form["email"] = "wichert@wiggy net"
             self.assertEqual(view._tryRegistration(), False)
-            self.failUnless("email" in view.errors)
+            self.assertTrue("email" in view.errors)
 
             view.errors.clear()
             view.request.form["email"] = "wichert@wiggy.net"
@@ -236,7 +232,7 @@ class ResetPasswordTests(EuphorieFunctionalTestCase):
             .get_payload(decode=True)
             .decode(mail.get_content_charset("utf-8"))
         )
-        self.failUnless(u"/passwordreset/" in body)
+        self.assertTrue(u"/passwordreset/" in body)
 
     def testInvalidResetKey(self):
         """When the request key is invalid the user is invited
@@ -253,7 +249,7 @@ class ResetPasswordTests(EuphorieFunctionalTestCase):
                 name="form.widgets.new_password"
             ).value = "secret"  # noqa: E501
             browser.getControl(
-                name="form.widgets.new_password.confirm"
+                name="form.widgets.new_password_confirmation"
             ).value = "secret"  # noqa: E501
             browser.getControl(label="Save changes").click()
             self.assertEqual(
