@@ -1,15 +1,11 @@
 from euphorie.client import model
 from euphorie.client.utils import HasText
 from euphorie.content.interfaces import IQuestionContainer
-from five import grok
 from z3c.saconfig import Session
 
 import collections
 
 
-grok.templatedir("templates")
-
-
 def getSurveyTree(survey, profile=None):
     """Return a list of all modules, profile questions and risks in
     a survey. Each entry is represented by a dict with a `zodb_path`
