@@ -9,14 +9,15 @@ import unittest
 
 
 def test_suite():
-    location = os.path.dirname(__file__) or '.'
+    location = os.path.dirname(__file__) or "."
     doctests = [
-        'stories/' + os.path.basename(test)
-        for test in glob.glob(os.path.join(location, 'stories', '*.txt'))
+        "stories/" + os.path.basename(test)
+        for test in glob.glob(os.path.join(location, "stories", "*.txt"))
     ]
 
     options = (
-        doctest.REPORT_ONLY_FIRST_FAILURE | doctest.ELLIPSIS
+        doctest.REPORT_ONLY_FIRST_FAILURE
+        | doctest.ELLIPSIS
         | doctest.NORMALIZE_WHITESPACE
     )
 
@@ -26,10 +27,11 @@ def test_suite():
                 test,
                 optionflags=options,
                 module_relative=True,
-                package='euphorie.content.tests',
-                encoding='utf-8',
+                package="euphorie.content.tests",
+                encoding="utf-8",
             ),
             layer=EUPHORIE_FUNCTIONAL_TESTING,
-        ) for test in doctests
+        )
+        for test in doctests
     ]
     return unittest.TestSuite(suites)
